<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'SINGLE_ModComments'           => 'Comment'                     , 
	'LBL_RECORDS_LIST'             => 'Comments List'               , 
	'LBL_MODCOMMENTS_INFORMATION'  => 'Comments'                    , 
	'LBL_OTHER_INFORMATION'        => 'Other Information'           , 
	'LBL_ADDING_COMMENT'           => 'Adding Comment'              , 
	'LBL_WRITE_YOUR_COMMENT_HERE'  => 'Enter comments here'         , 
	'Comment'                      => 'Comment'                     , 
	'Creator'                      => 'Creator'                     , 
	'Related To Comments'          => 'Se refera la'                , 
	'LBL_COMMENTED_AT'             => 'A comentat la'               , 
);